#---
# $Id: aradict.py,v 1.11 2003/07/05 05:16:26 elzubeir Exp $
#
# ------------
# Description:
# ------------
# The dict class should load the dictionary and compatibility tables into
# useful data structures. 
#
# (C) Copyright 2003, Arabeyes, Mohammed Elzubeir
# -----------------
# Revision Details:    (Updated by Revision Control System)
# -----------------
#  $Date: 2003/07/05 05:16:26 $
#  $Author: elzubeir $
#  $Revision: 1.11 $
#  $Source: /home/arabeyes/cvs/projects/duali/pyduali/pyduali/aradict.py,v $
#
#  This program is written under the BSD License.
#---

import anydbm
import aramisc
from arabic import *

class aradict:

  def __init__(self, data_path="../data/", verbose = 0):
    """
    Initialize the aradict class
    The default path to the data files is set to match the CVS heirarchy, this
    is unlikely to be the case once deployed
    """
    self.verbose = verbose
    #self.tableab = [] 
    #self.tableac = []
    #self.tablebc = []
    self.f_stems = "%s%s" % (data_path, "stems.db")
    self.f_pref = "%s%s" % (data_path, "prefixes.db")
    self.f_suf = "%s%s" % (data_path, "suffixes.db")
    #self.f_tableab = "%s%s" % (data_path, "tableab")
    #self.f_tableac = "%s%s" % (data_path, "tableac")
    #self.f_tablebc = "%s%s" % (data_path, "tablebc")

    try:
      self.stems = anydbm.open(self.f_stems)
      self.pref = anydbm.open(self.f_pref)
      self.suf = anydbm.open(self.f_suf)
    except:
      import sys
      print """
Fatal error opening dictionary db files. Please make sure that your path
includes the trailing slash (or backslash if on Windows)
"""
      sys.exit(0)
    #self.tableab = self.loadCTable(self.f_tableab)
    #self.tableac = self.loadCTable(self.f_tableac)
    #self.tablebc = self.loadCTable(self.f_tablebc)

  def getPrefix(self):
    "Return the prefix hash"
    return self.pref

  def getSuffix(self):
    "Return the suffix hash"
    return self.suf

  def getStem(self):
    "Return the stem hash"
    return self.stems
  
  def loadCTable(self, filename):
    "Load the compatibility tables from a file and return in a list"
    mytable = [] 
    lines = open(filename, 'r').readlines()
    for line in lines:
      line = aramisc.chomp(line)
      mytable.append(line)
    if (self.verbose):
      print "aradict::loadCTable()"
      print "\tReturning list of size: %d" % len(mytable)
    return mytable

